@@ -1,11 +1,10 @@
 import functools
-import inspect
 import types
 
-from newrelic.api.transaction import current_transaction
-from newrelic.api.object_wrapper import (ObjectWrapper,
-        callable_name, wrap_object)
-from newrelic.api.function_trace import FunctionTrace
+from .transaction import current_transaction
+from .function_trace import FunctionTrace
+from ..common.object_wrapper import FunctionWrapper, wrap_object
+from ..common.object_names import callable_name
 
 def GeneratorTraceWrapper(wrapped, name=None, group=None, label=None,
             params=None):
@@ -17,7 +16,7 @@ def GeneratorTraceWrapper(wrapped, name=None, group=None, label=None,
             return wrapped(*args, **kwargs)
 
         if callable(name):
-            if instance and inspect.ismethod(wrapped):
+            if instance is not None:
                 _name = name(instance, *args, **kwargs)
             else:
                 _name = name(*args, **kwargs)
@@ -29,7 +28,7 @@ def GeneratorTraceWrapper(wrapped, name=None, group=None, label=None,
             _name = name
 
         if callable(group):
-            if instance and inspect.ismethod(wrapped):
+            if instance is not None:
                 _group = group(instance, *args, **kwargs)
             else:
                 _group = group(*args, **kwargs)
@@ -38,7 +37,7 @@ def GeneratorTraceWrapper(wrapped, name=None, group=None, label=None,
             _group = group
 
         if callable(label):
-            if instance and inspect.ismethod(wrapped):
+            if instance is not None:
                 _label = label(instance, *args, **kwargs)
             else:
                 _label = label(*args, **kwargs)
@@ -47,7 +46,7 @@ def GeneratorTraceWrapper(wrapped, name=None, group=None, label=None,
             _label = label
 
         if callable(params):
-            if instance and inspect.ismethod(wrapped):
+            if instance is not None:
                 _params = params(instance, *args, **kwargs)
             else:
                 _params = params(*args, **kwargs)
@@ -110,7 +109,7 @@ def GeneratorTraceWrapper(wrapped, name=None, group=None, label=None,
                 else:
                     return result
 
-    return ObjectWrapper(wrapped, None, wrapper)
+    return FunctionWrapper(wrapped, wrapper)
 
 def generator_trace(name=None, group=None, label=None, params=None):
     return functools.partial(GeneratorTraceWrapper, name=name,
